@@ -13,15 +13,15 @@ A container for functions for the ack program.
 
 =head1 VERSION
 
-Version 2.999_05
+Version 2.999_06
 
 =cut
 
 our $VERSION;
 our $COPYRIGHT;
 BEGIN {
-    $VERSION = '2.999_05';
-    $COPYRIGHT = 'Copyright 2005-2018 Andy Lester.';
+    $VERSION = '2.999_06';
+    $COPYRIGHT = 'Copyright 2005-2019 Andy Lester.';
 }
 our $STANDALONE = 0;
 our $ORIGINAL_PROGRAM_NAME;
@@ -218,6 +218,21 @@ sub show_help {
 
     return show_help_types() if $help_arg =~ /^types?/;
 
+    my $manual_options;
+    if ( $App::Ack::STANDALONE ) {
+        $manual_options = <<'END';
+  --man                         Print the manual, FAQ and cookbook
+END
+    }
+    else {
+        $manual_options = <<'END';
+  --man                         Print the manual
+  --faq                         Print the frequently asked questions
+  --cookbook                    Print a list of tips and tricks for using ack
+END
+    }
+    chomp $manual_options;
+
     App::Ack::print( <<"END_OF_HELP" );
 Usage: ack [OPTION]... PATTERN [FILES OR DIRECTORIES]
 
@@ -242,8 +257,6 @@ Searching:
   -v, --invert-match            Invert match: select non-matching lines
   -w, --word-regexp             Force PATTERN to match only whole words
   -Q, --literal                 Quote all metacharacters; PATTERN is literal
-  --lines=NUM                   Only print line(s) NUM of each file.  No
-                                pattern is matched.
   --match PATTERN               Specify PATTERN explicitly. Typically omitted.
 
 Search output:
@@ -350,9 +363,7 @@ Miscellaneous:
   --[no]filter                  Force ack to treat standard input as a pipe
                                 (--filter) or tty (--nofilter)
   --help, -?                    This help
-  --man                         Print the manual
-  --faq                         Print the frequently asked questions
-  --cookbook                    Print a list of tips and tricks for using ack
+$manual_options
   --thpppt                      Bill the Cat
   --bar                         The warning admiral
   --cathy                       Chocolate! Chocolate! Chocolate!
@@ -420,27 +431,25 @@ END_OF_HELP
 sub show_docs {
     my $section = shift;
 
-    require Pod::Usage;
-
+    my $input;
     if ( $App::Ack::STANDALONE ) {
-        # Right now we just show all POD for the standalone.
-        Pod::Usage::pod2usage({
-            -input     => $App::Ack::ORIGINAL_PROGRAM_NAME,
-            -verbose   => 2,
-            -exitval   => 0,
-        });
+        # Standalone doesn't have the modules split out, so dump the entire file.
+        $input = $App::Ack::ORIGINAL_PROGRAM_NAME;
     }
     else {
         my $module = "App::Ack::Docs::$section";
         eval "require $module" or App::Ack::die( "Can't load $module" );
-
-        Pod::Usage::pod2usage({
-            -input     => $INC{ "App/Ack/Docs/$section.pm" },
-            -verbose   => 2,
-            -exitval   => 0,
-        });
+        $input = $INC{ "App/Ack/Docs/$section.pm" };
     }
 
+    require Pod::Usage;
+    Pod::Usage::pod2usage({
+        -input     => $input,
+        -verbose   => 2,
+        -exitval   => 0,
+        -noperldoc => 1, # Use Pod::Text.
+    });
+
     return;
 }
 
