@@ -27,6 +27,19 @@ Logic for loading configuration files.
 
 =cut
 
+sub opt_parser {
+    my @opts = @_;
+
+    my @standard = qw(
+        default
+        bundling
+        no_auto_help
+        no_auto_version
+        no_ignore_case
+    );
+    return Getopt::Long::Parser->new( config => [ @standard, @opts ] );
+}
+
 sub _invalid_combinations {
     my @context    = qw( -A -B -C --after-context --before-context --context );
     my @pretty     = qw( --heading --group --break );
@@ -36,7 +49,6 @@ sub _invalid_combinations {
     return (
         [qw(-l)]                 => [@context, @pretty, @filename, qw(-L -o --passthru --output --max-count --column -f -g --show-types)],
         [qw(-L)]                 => [@context, @pretty, @filename, qw(-l -o --passthru --output --max-count --column -f -g --show-types -c --count -v)],
-        [qw(--lines)]            => [@context, @pretty, @filename, qw(-l --files-with-matches --files-without-matches -L -o --passthru --match -m --max-count -1 -c --count --column --print0 -f -g --show-types)],
         [qw(-o)]                 => [@context, qw(--output -c --count --column --column -f --show-types)],
         [qw(--passthru)]         => [@context, @file_lists, qw(--output --column -m --max-count -1 -c --count -f -g)],
         [qw(--output)]           => [@context, @file_lists, qw(-c --count)],
@@ -49,7 +61,7 @@ sub _invalid_combinations {
         [@context]               => [@file_lists],
         [qw(-f)]                 => [qw(-g), @pretty],
         [qw(-g)]                 => [qw(-f), @pretty],
-        [qw(-p)]                 => [@context, @file_lists, qw( --passthru --lines -c )],
+        [qw(-p)]                 => [@context, @file_lists, qw( --passthru -c )],
     );
 }
 
@@ -87,13 +99,7 @@ sub _generate_ignore_dir {
         }
         else {
             $collection = App::Ack::Filter::Collection->new();
-
-            if ( $is_inverted ) {
-                push @{ $opt->{idirs} }, $collection->invert();
-            }
-            else {
-                push @{ $opt->{idirs} }, $collection;
-            }
+            push @{ $opt->{idirs} }, $is_inverted ? $collection->invert() : $collection;
         }
 
         $collection->add($filter);
@@ -166,12 +172,6 @@ sub _uninvert_filter {
 sub _process_filetypes {
     my ( $opt, $arg_sources ) = @_;
 
-    Getopt::Long::Configure('default', 'no_auto_help', 'no_auto_version'); # start with default options, minus some annoying ones
-    Getopt::Long::Configure(
-        'no_ignore_case',
-        'no_auto_abbrev',
-        'pass_through',
-    );
     my %additional_specs;
 
     my $add_spec = sub {
@@ -228,18 +228,17 @@ sub _process_filetypes {
         'type-del=s' => $delete_spec,
     );
 
+    my $p = opt_parser( 'no_auto_abbrev', 'pass_through' );
     foreach my $source (@{$arg_sources}) {
         my $args = $source->{contents};
 
         if ( ref($args) ) {
             # $args are modified in place, so no need to munge $arg_sources
-            local @ARGV = @{$args};
-            Getopt::Long::GetOptions(%type_arg_specs);
-            @{$args} = @ARGV;
+            $p->getoptionsfromarray( $args, %type_arg_specs );
         }
         else {
             ( undef, $source->{contents} ) =
-                Getopt::Long::GetOptionsFromString($args, %type_arg_specs);
+                $p->getoptionsfromstring( $args, %type_arg_specs );
         }
     }
 
@@ -326,7 +325,6 @@ sub get_arg_spec {
             }
             $opt->{ifiles}->add($filter);
         },
-        'lines=s'           => sub { shift; my $val = shift; push @{$opt->{lines}}, $val },
         'l|files-with-matches'
                             => \$opt->{l},
         'L|files-without-matches'
@@ -370,7 +368,7 @@ sub get_arg_spec {
                 App::Ack::die( "Unknown type '$value'" );
             }
         },
-        'u|underline!'      => \$opt->{u},
+        'underline!'        => \$opt->{underline},
         'v|invert-match'    => \$opt->{v},
         'w|word-regexp'     => \$opt->{w},
         'x'                 => sub { $opt->{files_from} = '-' },
@@ -392,40 +390,26 @@ sub _context_value {
 sub _process_other {
     my ( $opt, $extra_specs, $arg_sources ) = @_;
 
-    # Start with default options, minus some annoying ones.
-    Getopt::Long::Configure('default', 'no_auto_help', 'no_auto_version');
-    Getopt::Long::Configure(
-        'bundling',
-        'no_ignore_case',
-    );
-
     my $argv_source;
     my $is_help_types_active;
 
     foreach my $source (@{$arg_sources}) {
-        my ( $source_name, $args ) = @{$source}{qw/name contents/};
-
-        if ( $source_name eq 'ARGV' ) {
-            $argv_source = $args;
+        if ( $source->{name} eq 'ARGV' ) {
+            $argv_source = $source->{contents};
             last;
         }
     }
 
     if ( $argv_source ) { # This *should* always be true, but you never know...
-        my @copy = @{$argv_source};
-        local @ARGV = @copy;
-
-        Getopt::Long::Configure('pass_through');
-
-        Getopt::Long::GetOptions(
+        my $p = opt_parser( 'pass_through' );
+        $p->getoptionsfromarray( [ @{$argv_source} ],
             'help-types' => \$is_help_types_active,
         );
-
-        Getopt::Long::Configure('no_pass_through');
     }
 
     my $arg_specs = get_arg_spec($opt, $extra_specs);
 
+    my $p = opt_parser();
     foreach my $source (@{$arg_sources}) {
         my ( $source_name, $args ) = @{$source}{qw/name contents/};
 
@@ -457,13 +441,11 @@ sub _process_other {
 
         my $ret;
         if ( ref($args) ) {
-            local @ARGV = @{$args};
-            $ret = Getopt::Long::GetOptions( %{$args_for_source} );
-            @{$args} = @ARGV;
+            $ret = $p->getoptionsfromarray( $args, %{$args_for_source} );
         }
         else {
             ( $ret, $source->{contents} ) =
-                Getopt::Long::GetOptionsFromString( $args, %{$args_for_source} );
+                $p->getoptionsfromstring( $args, %{$args_for_source} );
         }
         if ( !$ret ) {
             if ( !$is_help_types_active ) {
@@ -482,34 +464,11 @@ sub _process_other {
 }
 
 
-sub _should_dump_options {
-    my ( $sources ) = @_;
-
-    foreach my $source (@{$sources}) {
-        my ( $name, $options ) = @{$source}{qw/name contents/};
-
-        if ( $name eq 'ARGV' ) {
-            my $dump;
-            local @ARGV = @{$options};
-            Getopt::Long::Configure('default', 'pass_through', 'no_auto_help', 'no_auto_version');
-            Getopt::Long::GetOptions(
-                'dump' => \$dump,
-            );
-            @{$options} = @ARGV;
-            return $dump;
-        }
-    }
-    return;
-}
-
-
 sub _explode_sources {
     my ( $sources ) = @_;
 
     my @new_sources;
 
-    Getopt::Long::Configure('default', 'pass_through', 'no_auto_help', 'no_auto_version');
-
     my %opt;
     my $arg_spec = get_arg_spec(\%opt);
 
@@ -531,6 +490,7 @@ sub _explode_sources {
         delete $arg_spec->{$arg};
     };
 
+    my $p = opt_parser( 'pass_through' );
     foreach my $source (@{$sources}) {
         my ( $name, $options ) = @{$source}{qw/name contents/};
         if ( ref($options) ne 'ARRAY' ) {
@@ -545,13 +505,12 @@ sub _explode_sources {
             $j--;
 
             my @copy = @chunk;
-            local @ARGV = @chunk;
-            Getopt::Long::GetOptions(
+            $p->getoptionsfromarray( [@chunk],
                 'type-add=s' => $add_type,
                 'type-set=s' => $add_type,
                 'type-del=s' => $del_type,
+                %{$arg_spec}
             );
-            Getopt::Long::GetOptions( %{$arg_spec} );
 
             push @new_sources, {
                 name     => $name,
@@ -586,12 +545,12 @@ sub _dump_options {
     my @source_names;
 
     foreach my $source (@{$sources}) {
-        my ( $name, $contents ) = @{$source}{qw/name contents/};
+        my $name = $source->{name};
         if ( not $opts_by_source{$name} ) {
             $opts_by_source{$name} = [];
             push @source_names, $name;
         }
-        push @{$opts_by_source{$name}}, $contents;
+        push @{$opts_by_source{$name}}, $source->{contents};
     }
 
     foreach my $name (@source_names) {
@@ -622,34 +581,23 @@ sub _remove_default_options_if_needed {
 
     my $should_remove = 0;
 
-    # Start with default options, minus some annoying ones.
-    Getopt::Long::Configure('default', 'no_auto_help', 'no_auto_version');
-    Getopt::Long::Configure(
-        'no_ignore_case',
-        'no_auto_abbrev',
-        'pass_through',
-    );
+    my $p = opt_parser( 'no_auto_abbrev', 'pass_through' );
 
     foreach my $index ( $default_index + 1 .. $#{$sources} ) {
         my $args = $sources->[$index]->{contents};
 
         if (ref($args)) {
-            local @ARGV = @{$args};
-            Getopt::Long::GetOptions(
+            $p->getoptionsfromarray( $args,
                 'ignore-ack-defaults' => \$should_remove,
             );
-            @{$args} = @ARGV;
         }
         else {
-            ( undef, $sources->[$index]{contents} ) = Getopt::Long::GetOptionsFromString($args,
+            ( undef, $sources->[$index]{contents} ) = $p->getoptionsfromstring( $args,
                 'ignore-ack-defaults' => \$should_remove,
             );
         }
     }
 
-    Getopt::Long::Configure('default');
-    Getopt::Long::Configure('default', 'no_auto_help', 'no_auto_version');
-
     return $sources unless $should_remove;
 
     my @copy = @{$sources};
@@ -727,19 +675,31 @@ sub process_args {
 
     $arg_sources = _remove_default_options_if_needed($arg_sources);
 
-    if ( _should_dump_options($arg_sources) ) {
-        _dump_options($arg_sources);
-        exit(0);
+    # Check for --dump early.
+    foreach my $source (@{$arg_sources}) {
+        if ( $source->{name} eq 'ARGV' ) {
+            my $dump;
+            my $p = opt_parser( 'pass_through' );
+            $p->getoptionsfromarray( $source->{contents},
+                'dump' => \$dump,
+            );
+            if ( $dump ) {
+                _dump_options($arg_sources);
+                exit(0);
+            }
+        }
     }
 
     my $type_specs = _process_filetypes(\%opt, $arg_sources);
+
     _process_other(\%opt, $type_specs, $arg_sources);
     while ( @{$arg_sources} ) {
         my $source = shift @{$arg_sources};
-        my ( $source_name, $args ) = @{$source}{qw/name contents/};
+        my $args = $source->{contents};
 
         # All of our sources should be transformed into an array ref
         if ( ref($args) ) {
+            my $source_name = $source->{name};
             if ( $source_name eq 'ARGV' ) {
                 @ARGV = @{$args};
             }
@@ -767,17 +727,12 @@ sub retrieve_arg_sources {
     my $noenv;
     my $ackrc;
 
-    Getopt::Long::Configure('default', 'no_auto_help', 'no_auto_version');
-    Getopt::Long::Configure('pass_through');
-    Getopt::Long::Configure('no_auto_abbrev');
-
-    Getopt::Long::GetOptions(
+    my $p = opt_parser( 'no_auto_abbrev', 'pass_through' );
+    $p->getoptions(
         'noenv'   => \$noenv,
         'ackrc=s' => \$ackrc,
     );
 
-    Getopt::Long::Configure('default', 'no_auto_help', 'no_auto_version');
-
     my @files;
 
     if ( !$noenv ) {
