@@ -297,14 +297,6 @@ identically to file type filters as seen in L</"Defining your own types">.
 
 Limit selected files to those with types that ack knows about.
 
-=item B<--lines=I<NUM>>
-
-Only print line I<NUM> of each file. Multiple lines can be given
-with multiple B<--lines> options or as a comma separated list
-(B<--lines=3,5,7>). Using a range such as B<--lines=4-7> also works. The
-lines are always output in the order found in the file, no matter the
-order given on the command line.
-
 =item B<-l>, B<--files-with-matches>
 
 Only print the filenames of matching files, instead of the matching text.
@@ -531,10 +523,10 @@ also L</"Defining your own types">.
 The filters associated with TYPE are removed from Ack, and are no longer considered
 for searches.
 
-=item B<-u>, B<--[no]underline>
+=item B<--[no]underline>
 
-Turns on underlining of matches, where "underlining" is not a true
-underlining, but printing a line of carets under the match.
+Turns on underlining of matches, where "underlining" is printing a line of
+carets under the match.
 
     $ ack -u foo
     peanuts.txt
@@ -544,7 +536,7 @@ underlining, but printing a line of carets under the match.
                           ^^^
 
 This is useful if you're dumping the results of an ack run into a text
-file or printer and don't get any coloring.
+file or printer that doesn't support ANSI color codes.
 
 The setting of underline does not affect highlighting of matches.
 
@@ -1099,7 +1091,7 @@ Andy Lester, C<< <andy at petdance.com> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2005-2018 Andy Lester.
+Copyright 2005-2019 Andy Lester.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the Artistic License v2.0.
